Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Options ¶
type Options struct {
// Name of the engine to use when opening the database.
// Must be either "memory", "bolt" or "badger"
// If empty, "memory" will be used, unless DBPath is non empty.
// In that case "bolt" will be used.
Engine string
// Path of the database file or directory that will be created.
DBPath string
}
Options of the shell.
Click to show internal directories.
Click to hide internal directories.